@@ -1,8 +1,7 @@
-import warnings
-
-from django.utils.encoding import force_unicode
+from __future__ import unicode_literals
 
 from selectable.base import LookupBase, ModelLookup
+from selectable.compat import force_text
 from selectable.exceptions import (LookupAlreadyRegistered, LookupNotRegistered,
                                     LookupInvalid)
 
@@ -14,25 +13,20 @@ class LookupRegistry(object):
 
     def validate(self, lookup):
         if not issubclass(lookup, LookupBase):
-            raise LookupInvalid(u'Registered lookups must inherit from the LookupBase class')
-        if issubclass(lookup, ModelLookup) and getattr(lookup, 'search_field', None):
-            warnings.warn(
-                u"ModelLookup.search_field is deprecated; Use ModelLookup.search_fields instead.", 
-                DeprecationWarning, stacklevel=2
-            )
+            raise LookupInvalid('Registered lookups must inherit from the LookupBase class')
 
     def register(self, lookup):
         self.validate(lookup)
-        name = force_unicode(lookup.name())
+        name = force_text(lookup.name())
         if name in self._registry:
-            raise LookupAlreadyRegistered(u'The name %s is already registered' % name)
+            raise LookupAlreadyRegistered('The name %s is already registered' % name)
         self._registry[name] = lookup
 
     def unregister(self, lookup):
         self.validate(lookup)
-        name = force_unicode(lookup.name())
+        name = force_text(lookup.name())
         if name not in self._registry:
-           raise LookupNotRegistered(u'The name %s is not registered' % name)
+           raise LookupNotRegistered('The name %s is not registered' % name)
         del self._registry[name]
 
     def get(self, key):
