@@ -1,4 +1,5 @@
-# -*- encoding: utf-8 -*-
+from __future__ import unicode_literals
+
 from django import template
 from django.conf import settings
 
